@@ -46,16 +46,16 @@ def keysplit(key):
     """
     keysplit(key) -> (folder, id)
     """
-    parts = key.split("/")
-    return ("/".join(parts[:-1]), parts[-1])
+    parts = key.split('/')
+    return ('/'.join(parts[:-1]), parts[-1])
 
 
 def locationsplit(location):
     """
     locationsplit(location) -> (section, folder, id)
     """
-    parts = key.split("/")
-    return (parts[0], "/".join(parts[1:-1]), parts[-1])
+    parts = key.split('/')
+    return (parts[0], '/'.join(parts[1:-1]), parts[-1])
 
 
 def titlespace(s):
@@ -68,7 +68,7 @@ def titlespace(s):
     'This Would Be Better With Spaces'
     """
     return "".join([s[0]] + [
-        " " + char if char.isupper() else char for char in s[1:]])
+        ' ' + char if char.isupper() else char for char in s[1:]])
 
 
 def validate(value, rule):
@@ -80,18 +80,18 @@ def validate(value, rule):
 
     Available rules are in the validators dict.
 
-    >>> validate(23, "min 0|max 20")
+    >>> validate(23, 'min 0|max 20')
     False
-    >>> validate([0, 5, 12, 19], "min 0|max 20")
+    >>> validate([0, 5, 12, 19], 'min 0|max 20')
     True
-    >>> validate("10.10.10.10", "ipv4")
+    >>> validate("10.10.10.10", 'ipv4')
     True
-    >>> validate({"a":1,"b":2,"c":3}, "a|b")
+    >>> validate({'a':1,'b':2,'c':3}, 'a|b')
     True
     """
     if isinstance(value, dict):
         # only validator for dict is to see if keys exist
-        for r in rule.split("|"):
+        for r in rule.split('|'):
             if r not in value:
                 return False
         return True
@@ -102,7 +102,7 @@ def validate(value, rule):
                 return False
         return True
     try:
-        for r in rule.split("|"):
+        for r in rule.split('|'):
             # todo: improve re to allow escape quoted strings in rules
             #          none of current validators require this
             parts = re.findall(r'(?:(?<=["\']).*?(?=["\'])|\w+)', r)
@@ -200,24 +200,33 @@ def isurl(value):
         r'(?:/?|[/?]\S+)$', re.IGNORECASE)
     return url_regex.match(value) is not None
 
+def alwaysvalid(value):
+    return True
+
 # each entry in validators is a class with a dict of rules
 # each rule is a name with a tuple of the function and the class
 # types for any arguments to the function
 
 validators = {
+    bool: {
+        'boolean': (alwaysvalid,)
+        },
     float: {
+        'float': (alwaysvalid,),
         'min': (float.__ge__, float),
         'max': (float.__le__, float),
         '>': (float.__gt__, float),
         '<': (float.__lt__, float)
         },
     int: {
+        'integer': (alwaysvalid,),
         'min': (int.__ge__, int),
         'max': (int.__le__, int),
         '>': (int.__gt__, int),
         '<': (int.__lt__, int)
         },
     str: {
+        'string': (alwaysvalid,),
         'min': (lambda s, v: len(s) >= v, int),
         'max': (lambda s, v: len(s) <= v, int),
         'url': (isurl,),
@@ -234,29 +243,35 @@ class Field:
         object.__setattr__(self, 'value', value)
 
     def __str__(self):
+        """x.__str__() <==> str(x)"""
         return str(self.value)
 
     def __repr__(self):
-        return "Field({})".format(repr(self.value))
+        """x.__repr__() <==> repr(x)"""
+        return 'Field({})'.format(repr(self.value))
 
     def __getattr__(self, name):
+        """x.__getattr__('y') <==> x.y"""
         if hasattr(self.__dict__['value'], name):
             return getattr(self.value, name)
         raise AttributeError
 
     def __setattr__(self, name, value):
+        """x.__setattr__('y', z) <==> x.y = z"""
         if name == 'value':
             if hasattr(self.value, name):
                 return self.value.__setattr__(name, value)
         return object.__setattr__(self, name, value)
 
     def __getitem__(self, name):
+        """x.__getitem__(y) <==> x[y]"""
         if isinstance(name, int):
             return self.value.values()[name]
         else:
             return self.value[name]
 
     def __setitem__(self, name, value):
+        """x.__setitem__(y, z) <==> x[y] = z"""
         self.value[name] = value
 
     def jsonencode(self):
@@ -276,10 +291,12 @@ class Path:
             self.path = self.root.join(*location.split('/'))
 
     def __str__(self):
+        """x.__str__() <==> str(x)"""
         return str(self.path)
 
     def __repr__(self):
-        return "Path({}, {})".format(repr(self.root), repr(self.location))
+        """x.__repr__() <==> repr(x)"""
+        return 'Path({}, {})'.format(repr(self.root), repr(self.location))
 
     @property
     def exists(self):
@@ -302,9 +319,10 @@ class Path:
             os.makedirs(p)
 
     def lock(self):
+        """Aquire lock on self.path"""
         if hasattr(self, '_lock'):
             return
-        lock = self.path + ".lock"
+        lock = self.path + '.lock'
         self.make()
         repeats = LOCK_RETRY
         while repeats and os.path.exists(lock):
@@ -316,6 +334,7 @@ class Path:
         self._lock = lock
 
     def release(self):
+        """Release lock on self.path"""
         if hasattr(self, '_lock'):
             os.remove(self._lock)
             del(self._lock)
@@ -353,8 +372,8 @@ class ListFile(Path):
             for line in self.walk():
                 if line == str(value):
                     return
-            with self.open("a") as file:
-                file.write(str(value) + "\n")
+            with self.open('a') as file:
+                file.write(str(value) + '\n')
 
     def extend(self, iterable):
         """
@@ -371,16 +390,20 @@ class ListFile(Path):
         Removes a unique value from location.
         """
         if value not in [None, "", [], {}, ()] and self.exists:
+            changed = False
             with tempfile.NamedTemporaryFile(
-                    prefix="deepdesk", delete=False) as new:
+                    prefix='deepdesk', delete=False) as new:
                 newname = new.name
                 for line in self.walk():
                     if line != value:
-                        new.write(line.encode("utf-8"))
-            if os.path.getsize(newname):
-                shutil.copyfile(newname, self.path)
-            else:
-                os.remove(self.path)
+                        new.write((line + '\n').encode('utf-8'))
+                    else:
+                        changed = True
+            if changed:
+                if os.path.getsize(newname):
+                    shutil.copyfile(newname, self.path)
+                else:
+                    os.remove(self.path)
             os.remove(newname)
 
 
@@ -389,7 +412,7 @@ class IndexFile(Path):
     An IndexFile is a store of unique entry, value pairs.
     """
     def __init__(self, root, location):
-        Path.__init__(self, root, "index/" + location)
+        Path.__init__(self, root, 'index/' + location)
 
     def lookup(self, entry, reverse=False):
         """
@@ -406,14 +429,14 @@ class IndexFile(Path):
             if e.startswith(folder):
                 e = e[len(folder):]
         else:
-            e = e.replace(" ", "_")
+            e = e.replace(' ', '_')
         for entry, value in self.walk():
             if reverse:
                 if value == e:
                     return entry
             else:
                 if entry == e:
-                    if value[0] == "/":
+                    if value[0] == '/':
                         value = folder + value
                     return value
         return None
@@ -424,7 +447,7 @@ class IndexFile(Path):
             folder = keysplit(self.location[6:])[0]
             with self.open('r') as file:
                 for line in file:
-                    entry, value = line.split(" ", 1)
+                    entry, value = line.split(' ', 1)
                     yield (entry, value.strip())
 
     def write(self, entry, value):
@@ -435,7 +458,7 @@ class IndexFile(Path):
                         "domino.marama@example.com",
                         "person/domino.marama")
         """
-        e = str(entry).replace(" ", "_")
+        e = str(entry).replace(' ', '_')
         v = str(value)
         b = keysplit(self.location[6:])[0]
         if v.startswith(b):
@@ -443,24 +466,28 @@ class IndexFile(Path):
         if self.exists:
             self.delete(e)
         if value not in [None, "", [], {}, ()]:
-            with self.open("a") as file:
-                file.write("{} {}\n".format(e, v))
+            with self.open('a') as file:
+                file.write('{} {}\n'.format(e, v))
 
     def delete(self, entry):
         """
         Deletes any references to entry from filename.
         """
         if self.exists:
+            changed = False
             with tempfile.NamedTemporaryFile(
-                    prefix="deepdesk", delete=False) as new:
+                    prefix='deepdesk', delete=False) as new:
                 newname = new.name
                 for e, value in self.walk():
                     if e != entry:
-                        new.write((e + " " + value + "\n").encode("utf-8"))
-            if os.path.getsize(newname):
-                shutil.copyfile(newname, self.path)
-            else:
-                os.remove(self.path)
+                        new.write((e + ' ' + value + '\n').encode('utf-8'))
+                    else:
+                        changed = True
+            if changed:
+                if os.path.getsize(newname):
+                    shutil.copyfile(newname, self.path)
+                else:
+                    os.remove(self.path)
             os.remove(newname)
 
 
@@ -472,7 +499,7 @@ class Record(Path):
         """Record on disk has not been updated since record loaded"""
         return self.last_saved == self.last_modified
 
-    def __init__(self, root, key="record", indict=None, profile="deepdesk"):
+    def __init__(self, root, key='record/', indict=None, profile='deepdesk'):
         assert isinstance(root, Root)
         self.profile = profile
         self.owner = profile
@@ -485,30 +512,35 @@ class Record(Path):
         self.privs = None
         self.fields = {}
         self.last_saved = None
-        if str(key).startswith("|"):
+        if isinstance(key, list):
+            self.alias = key[1:]
+            key = key[0]
+        else:
+            self.alias = []
+        if str(key).startswith('|'):
             hook = includehook
             key = str(key)[1:]
         else:
             hook = loadhook
         self.key = Key(str(key))
-        if self.key.value.endswith("/"):
-            if self.key.value.startswith("data/"):
+        if self.key.value.endswith('/'):
+            if self.key.value.startswith('data/'):
                 template = Record(
                     self.root,
-                    self.key.value.replace("data/", "|template/"))[:-1]
+                    self.key.value.replace('data/', '|template/'))[:-1]
             else:
                 template = Record(
                     self.root,
-                    "|template/" + self.key.value[:-1])
+                    '|template/' + self.key.value[:-1])
             if template.exists:
                 self.base = template.key.location[:-5]
                 self.importrecord(template.fields)
-            self.key.value += str(uuid.uuid4()).replace("-", "/")
+            self.key.value += str(uuid.uuid4()).replace('-', '/')
             self.path = self.root.join(self.key.location)
         else:
             self.path = self.root.join(self.key.location)
             try:
-                self.path = max(glob(self.path[:-5] + "*.json"))
+                self.path = max(glob(self.path[:-5] + '.*.json'))
                 self.key = Key(self.path[len(self.root.basepath) + 1:])
                 self.version = int(self.key.value[-9:-5])
             except:
@@ -539,21 +571,39 @@ class Record(Path):
         elif isinstance(item, Key):
             listfile = ListFile(
                 self.root,
-                Key(item.value).location[:-5] + ".ref")
+                Key(item.value).location[:-5] + '.ref')
             listfile.remove(str(self.key))
-        elif isinstance(item, Alias):
-            path = Path(self.root, Key(item.alias).location)
-            if path.exists:
-                path.lock()
-                os.remove(path.path)
-                path.release()
         elif isinstance(item, (list, tuple)):
             for i in item:
                 self.deindex(i)
         elif isinstance(item, dict):
             self.deindex(list(item.values()))
-        os.remove(self.path[:-5] + ".cit")
-        # todo deindex Search & Group objects
+        if item == self.fields:
+            alias = ListFile(self.root, self.key.location[:-5] + '.alias')
+            if alias.exists:
+                for key in alias.walk():
+                    path = Path(self.root, key)
+                    if os.path.islink(path.path):
+                        os.remove(path.path)
+                os.remove(alias.path)
+            groups = ListFile(self.root, self.key.location[:-5] + '.groups')
+            if groups.exists:
+                for group in groups.walk():
+                    listfile = ListFile(self.root, 'group/' + group)
+                    listfile.remove(self.key)
+                os.remove(groups.path)
+            words = ListFile(self.root, self.key.location[:-5] + '.words')
+            if words.exists:
+                for word in words.walk():
+                    parts = re.findall(
+                        '.' * self.root._search['pathsplit'], word)
+                    listfile = ListFile(
+                        self.root,
+                        '/'.join(['search', '/'.join(parts), word]))
+                    listfile.remove(self.key)
+                os.remove(words.path)
+            if os.path.exists(self.path[:-5] + '.cit'):
+                os.remove(self.path[:-5] + '.cit')
 
     def importrecord(self, indict):
         """Imports indict into this record."""
@@ -603,32 +653,41 @@ class Record(Path):
         elif isinstance(item, Collect):
             if item.active and item.collect and item.value is not None:
                 listfile = ListFile(
-                    self.root, "/".join("collection", item.collection))
+                    self.root, '/'.join('collection', item.collection))
                 listfile.append(item.value)
         elif isinstance(item, Key):
             if item.value != self.key.value:
-                if not item.value.endswith("/"):
-                    listfile = ListFile(self.root, self.key.location[:-5] + ".cit")
+                if not item.value.endswith('/'):
+                    listfile = ListFile(
+                        self.root,
+                        self.key.location[:-5] + '.cit')
                     listfile.append(item)
                     listfile = ListFile(
                         self.root,
-                        Key(item.value).location[:-5] + ".ref")
+                        Key(item.value).location[:-5] + '.ref')
                     listfile.append(self.key)
         elif isinstance(item, Group):
             if item.index and item.value is not None:
                 if item.value not in ["", [], ()]:
+                    groups = ListFile(
+                        self.root,
+                        self.key.location[:-5] + '.groups')
                     if not isinstance(item.value, dict):
                         if not isinstance(item.value, (list, tuple)):
                             v = [item.value]
                         else:
                             v = item.value
                     for value in v:
-                        listfile = ListFile(self.root, "group/" + item.group)
-                        list.append(self.key)
+                        listfile = ListFile(
+                            self.root,
+                            '/'.join(['group', item.group, value]))
+                        listfile.append(self.key)
+                        groups.append('/'.join([item.group, value]))
         elif isinstance(item, Search):
             if item.value:
                 stemmer = Path(tempfile.gettempdir(), 'deepdesk.stemmer')
                 stemmer.lock()
+                words = ListFile(self.root, self.key.location[:-5] + '.words')
                 for word in [
                         w.lower() for w in set(
                             self.root._stemmer.stemWords(item.value.split()))
@@ -639,6 +698,7 @@ class Record(Path):
                         self.root,
                         '/'.join(['search', '/'.join(parts), word]))
                     listfile.append(self.key)
+                    words.append(word)
                 stemmer.release()
         elif isinstance(item, (list, tuple)):
             for i in item:
@@ -648,8 +708,14 @@ class Record(Path):
         elif isinstance(item, Field):
             indexed = indexed or self.reindex(item.value)
         if item == self.fields:
+            for key in self.alias:
+                self.storealias(key)
+                alias = ListFile(
+                    self.root,
+                    self.key.location[:-5] + '.alias')
+                alias.append(key)
             if not indexed:
-                listfile = ListFile(self.root, "index/unindexed")
+                listfile = ListFile(self.root, 'index/unindexed')
                 listfile.append(self.key)
         else:
             return indexed
@@ -658,19 +724,21 @@ class Record(Path):
         """Save this record to disk."""
         if hasattr(self, 'version'):
             try:
-                path = max(glob(self.root.join(str(self.key) + "*.json")))
+                path = max(glob(self.root.join(str(self.key) + '.*.json')))
                 self.version = int(path[-9:-5]) + 1
             except:
                 pass
-            n = "000" + str(self.version)
-            self.key.value = str(self.key) + "." + n[-4:] + ".json"
+            n = '000' + str(self.version)
+            self.key.value = str(self.key) + '.' + n[-4:] + '.json'
             self.path = self.root.join(self.key.value)
-        with self.open("w") as file:
+        if self.exists and not self.key.startswith('template/'):
+            self.deindex()
+        with self.open('w') as file:
             if self.root.pretty:
                 json.dump(self, file, indent=4, sort_keys=True, cls=encoder)
             else:
                 json.dump(self, file, separators=(',', ':'), cls=encoder)
-        if not self.key.startswith("template"):
+        if not self.key.startswith('template/'):
             self.reindex()
 
     def storealias(self, alias):
@@ -731,10 +799,10 @@ class Record(Path):
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        s = "indict={}".format(repr(self.fields))
+        s = 'indict={}'.format(repr(self.fields))
         if self.key.value:
-            s = "key={}, ".format(repr(self.key.location)) + s
-        return "Record({}, profile={})".format(s, repr(self.profile))
+            s = 'key={}, '.format(repr(self.key.location)) + s
+        return 'Record({}, profile={})'.format(s, repr(self.profile))
 
     def __str__(self):
         """x.__str__() <==> str(x)"""
@@ -746,13 +814,20 @@ class Record(Path):
 
     def jsonencode(self):
         """Returns a json representation of the object."""
+        if self.alias:
+            key = [self.key.clean] + self.alias
+        else:
+            key = self.key.clean
         d = {
-            '__record__': self.key.clean,
+            '__record__': key,
             'value': self.fields}
         d['owner'] = self.owner
         d['created'] = self.created
         if self.hash:
-            d['hash'] = binascii.b2a_hex(self.hash).decode()
+            if self.hash == True:
+                d['hash'] = True
+            else:
+                d['hash'] = binascii.b2a_hex(self.hash).decode()
             if self.salt:
                 d['salt'] = self.salt
             else:
@@ -772,7 +847,7 @@ class Root:
 
         # Setup stemmer for search term reduction
 
-        self._search = Record(self, "deepdesk/search")
+        self._search = Record(self, 'deepdesk/search')
         if not self._search.exists:
             self._search.fields.update(
                 {
@@ -787,13 +862,16 @@ class Root:
             self._search['stemmer'], self._search['cache'])
 
     def __len__(self):
+        """x.__len__() <==> len(x)"""
         return len(self.basepath)
 
     def __str__(self):
+        """x.__str__() <==> str(x)"""
         return str(self.basepath)
 
     def __repr__(self):
-        return "Root({})".format(repr(self.basepath))
+        """x.__repr__() <==> repr(x)"""
+        return 'Root({})'.format(repr(self.basepath))
 
     def join(self, *args):
         """
@@ -813,10 +891,10 @@ class Root:
 
         >>> browse('data')
         ['menu', 'imports', 'schema.org', 'deepdesk']
-        >>> browse("data/menu/schema.org")
+        >>> browse('data/menu/schema.org')
         ['Data Type', 'Thing', 'Data Type.json', 'Thing.json']
         """
-        if location.endswith("*"):
+        if location.endswith('*'):
             path = self.join(*location.split('/')[:-1])
             start = location.split('/')[-1][:-1]
         else:
@@ -838,13 +916,14 @@ class Root:
         # setup system records
         if not self._search.exists:
             self._search.save()
+
         # import schema.org
-        schema = Record(self, "imports/schema.org")
+        schema = Record(self, 'imports/schema.org')
         if not schema.exists:
             schema.fields = requests.get(
-                "http://schema.rdfs.org/all.json").json()
+                'http://schema.rdfs.org/all.json').json()
             schema.save()
-        r = Record(self, "schema.org")
+        r = Record(self, 'schema.org')
         update = True
         if r.exists:
             if schema['valid'] != r['valid']:
@@ -860,11 +939,11 @@ class Root:
                 for datatype in schema[section]:
                     if section == 'valid':
                         continue
-                    key = "schema.org/" + schema[section][datatype]['id']
+                    key = 'schema.org/' + schema[section][datatype]['id']
                     record = Record(
                         self, key, indict=schema[section][datatype])
                     record['id'] = \
-                        Key("schema.org/" + str(record['id'])).clean
+                        Key('schema.org/' + str(record['id'])).clean
                     for name in [
                             'supertypes',
                             'ancestors',
@@ -875,15 +954,15 @@ class Root:
                             'ranges']:
                         if name in record.fields:
                             record[name] = [
-                                Key("schema.org/" + a)
+                                Key('schema.org/' + a)
                                 for a in record[name]]
                     if not isinstance(record['label'], Search):
                         record['label'] = Search(record['label'])
-                    record.save()
                     if 'ancestors' in record.fields and section.endswith('types'):
-                        alias = "/".join(['menu', 'schema.org'] + [
-                            titlespace(keysplit(s.clean)[1]) for s in record['ancestors']] + [str(record['label'])]) + ".json"
-                        record.storealias(alias)
+                        alias = '/'.join(['menu', 'schema.org'] + [
+                            titlespace(keysplit(s.clean)[1]) for s in record['ancestors']] + [str(record['label'])]) + '.json'
+                        record.alias.append(alias)
+                    record.save()
 
     def search(self, value):
         """
@@ -912,7 +991,7 @@ class Root:
                 if w.lower() not in self._search['stopwords']]:
             parts = re.findall('.' * self._search['pathsplit'], word)
             searchindex = ListFile(
-                self, "/".join(['search', "/".join(parts), word]))
+                self, '/'.join(['search', '/'.join(parts), word]))
             if not result:
                 result = set(searchindex.load())
             else:
@@ -948,13 +1027,14 @@ class Key(Field):
     """
     @property
     def clean(self):
+        """Returns cleaned (shortest) version of the key."""
         key = self.value
-        if key.startswith("data/"):
+        if key.startswith('data/'):
             key = key[5:]
-        if key.endswith(".json"):
+        if key.endswith('.json'):
             key = key[:-5]
         try:
-            e = key.split(".")[-1]
+            e = key.split('.')[-1]
             if len(e) != 4:
                 raise Exception
             i = int(e)
@@ -965,62 +1045,63 @@ class Key(Field):
 
     @property
     def location(self):
-        if self.value.endswith("/"):
+        """Returns full version of the key."""
+        if self.value.endswith('/'):
             folder = self.value[:-1]
             id = ""
-            extension = ".json"
+            extension = '.json'
         else:
             basekey, ext = os.path.splitext(self.value)
             try:
                 version = int(ext[1:])
                 basekey += ext
-                extension = ".json"
+                extension = '.json'
             except:
-                if ext != ".json":
-                    extension = ".json"
+                if ext != '.json':
+                    extension = '.json'
                     basekey += ext
                 else:
                     extension = ext
             try:
                 # versioned record
-                e = basekey.split(".")[-1]
+                e = basekey.split('.')[-1]
                 if len(e) != 4:
                     raise Exception
                 version = int(e)
-                basekey = ".".join(basekey.split(".")[:-1])
+                basekey = '.'.join(basekey.split('.')[:-1])
             except:
                 pass
             try:
                 # uuid record
-                if basekey[-37] != "/":
+                if basekey[-37] != '/':
                     raise Exception
-                id = str(uuid.UUID(value[-36:].replace("/", "-")))
+                id = str(uuid.UUID(value[-36:].replace('/', '-')))
                 folder = value[:-37]
             except:
                 folder, id = keysplit(basekey)
                 if not id:
                     id = folder
                     folder = ""
-        if folder.startswith(("template/", "data/", "deepdesk/", "menu/")) or\
-                folder in ["template", "data", "deepdesk", "menu"]:
+        if folder.startswith(('template/', 'data/', 'deepdesk/', 'menu/')) or\
+                folder in ['template', 'data', 'deepdesk', 'menu']:
             section = ""
         else:
             if folder == "":
                 section = ""
                 if id == "":
-                    id = "data"
+                    id = 'data'
                 else:
-                    folder = "data"
+                    folder = 'data'
             else:
-                section = "data"
-        loc = "/".join([section, folder, id]) + extension
-        while loc[0] == "/":
+                section = 'data'
+        loc = '/'.join([section, folder, id]) + extension
+        while loc[0] == '/':
             loc = loc[1:]
         return loc
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "Key({})".format(repr(self.clean))
+        return 'Key({})'.format(repr(self.clean))
 
     def __str__(self):
         """x.__str__() <==> str(x)"""
@@ -1030,7 +1111,6 @@ class Key(Field):
         """Returns a json representation of the object."""
         return {'__key__': self.clean}
 
-
 class Index(Field):
     """
     Index field wrapper.
@@ -1043,7 +1123,7 @@ class Index(Field):
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "Index({}, {})".format(repr(self.value), repr(self.index))
+        return 'Index({}, {})'.format(repr(self.value), repr(self.index))
 
     def jsonencode(self):
         """Returns a json representation of the object."""
@@ -1062,7 +1142,7 @@ class Access(Field):
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "Access({}, {})".format(repr(self.value), repr(self.access))
+        return 'Access({}, {})'.format(repr(self.value), repr(self.access))
 
     def jsonencode(self):
         """Returns a json representation of the object."""
@@ -1087,7 +1167,7 @@ class Collect(Field):
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "Collect({}, {}, {})".format(
+        return 'Collect({}, {}, {})'.format(
             repr(self.value), repr(self.collection), repr(self.active))
 
     def jsonencode(self):
@@ -1110,7 +1190,7 @@ class Group(Field):
 
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "Group({}, {})".format(repr(self.value), repr(self.group))
+        return 'Group({}, {})'.format(repr(self.value), repr(self.group))
 
     def jsonencode(self):
         """Returns a json representation of the object."""
@@ -1136,7 +1216,7 @@ class Search(Field):
     """
     def __repr__(self):
         """x.__repr__() <==> repr(x)"""
-        return "Search({})".format(repr(self.value))
+        return 'Search({})'.format(repr(self.value))
 
     def jsonencode(self):
         """Returns a json representation of the object."""
@@ -1157,7 +1237,8 @@ class Validate(Field):
         self.rule = rule
 
     def __repr__(self):
-        return ("Validate({}, {})".format(repr(self.value), repr(self.rule)))
+        """x.__repr__() <==> repr(x)"""
+        return ('Validate({}, {})'.format(repr(self.value), repr(self.rule)))
 
     def jsonencode(self):
         """Returns a json representation of the object."""
